@@ -2,18 +2,19 @@ package Test::Auto::Plugin::ShortDescription;
 
 use strict;
 use warnings;
-use routines;
 
+use Moo;
 use Test::More;
-use Data::Object::Class;
-use Data::Object::Attributes;
 
 extends 'Test::Auto::Plugin';
 
-method tests(:$length = 160) {
+sub tests {
+  my ($self, %args) = @_;
+
+  my $length = $args{length} || 160;
   my $parser = $self->subtests->parser;
 
-  subtest "testing description length ($length)", fun () {
+  subtest "testing description length ($length)", sub {
     my $description = $parser->render('description')
       or plan skip_all => 'no description';
 
